<?php


namespace App\Http\Controllers\Admin;


use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Gate;
use App\User;
use App\Role;
use App\RoleUser;
use App\Locales;
use App\Config;
use App\Maintenance;
use App\TranslationsCms;

class SettingsController extends Controller
{

    protected $cachePath ;


    public function __construct()
    {
        $this->cachePath = storage_path('framework/views/');



    }

    public function  index(Request $request){

        if(Gate::denies('settings')){
            addlog(tc('no.permission.error.msg') ,'100');
            session()->flash('error', tc('no.permission.error.msg'));
            return redirect()->route('cms.dashboard');
        }


        $users = User::get();
        $roles = Role::get();

        $ips = Maintenance::get();
        $pagin = count(getLocales()) * 10;

        if($request->search) {
            $search = $request->search;

            $trans = TranslationsCms::where("trans_key", "LIKE", "%$search%")->orWhere("value", "LIKE", "%$search%")->orderBy('trans_key', 'ASC')->paginate($pagin);
        } else{
            $trans = TranslationsCms::orderBy('trans_key', 'ASC')->paginate($pagin);
        }

        return view('backend.pages.settings.settings',['langs'=>getLocales(),'users'=>$users,'roles' => $roles,'ips'=>$ips,'trans'=>$trans]);

    }

    public function clearCache()
    {
        File::cleanDirectory($this->cachePath);
        return 1;
    }

    public function edituser(Request $request)
    {
        $user = User::findOrFail($request->userid);
        $roles = $user->roles;



        return ['user' =>$user, 'roles'=>$roles];
    }

    public function editusersave(Request $request)
    {
        if($request->userid == null){
            $checkuser = User::where('email', $request->email)->first();

            if(!empty($checkuser->email)){
                addlog(tc('mail.unique.error.msg') ,'200');
                session()->flash('error', tc('mail.unique.error.msg'));
                return redirect()->route('cms.settings');
            } else {
                $user = New User();
            }



        }else{
            $user = User::findOrFail($request->userid);
        }
        $user->name = $request->name;
        $user->surname = $request->surname;

        $user->phone = $request->phone;

        $user->email = $request->email;
        $user->job_title = $request->job_title;
        if($request->password){
            $user->password =  bcrypt($request->password);
        }
        $user->save();
        if($request->userid != null) {
            RoleUser::where('user_id', $request->userid)->delete();
        }



        if($request->rules) {
            foreach ($request->rules as $rule) {
                $roles = New RoleUser();
                if($request->userid != null) {
                    $roles->user_id = $request->userid;
                } else{
                    $roles->user_id = $user->id;
                }
                $roles->role_id = $rule;
                $roles->save();
            }
        }







        if($request->userid){
            session()->flash('success', tc('user.edited.msg'));
            addlog(tc('user.edited.msg').' - '. $user->name .' ' .$user->surname .' ელ.ფოსტა' .$user->email .' User id:' .$user->id,'500');

        } else{
            session()->flash('success', tc('user.added.msg'));
            addlog(tc('user.added.msg') .' - '. $request->name .' ' .$request->surname .' ' .$request->email,'400');


        }

        return redirect()->route('cms.settings');

    }

    public function removeuser(Request $request)
    {

        if($request->deluserid){
            $user = User::findOrFail($request->deluserid);
            addlog(tc('user.deleted.msg').' - '. $user->name .' ' .$user->surname .' ელ.ფოსტა' . $user->email .' User id:' .$user->id,'600');
            RoleUser::where('user_id', $request->deluserid)->delete();
            User::where('id', $request->deluserid)->delete();
        }


        session()->flash('success', tc('user.deleted.msg'));
        return redirect()->route('cms.settings');

    }

    public function editlang(Request $request)
    {
        $locale = Locales::findOrFail($request->langid);

        return ['lang' =>$locale];
    }

    public function editlangsave(Request $request)
    {
        if($request->langid == null){
            $locale = New Locales();

            addlog(tc('new.lang.add.msg'),'400');
            session()->flash('success', tc('new.lang.add.msg'));
        }else{
            $locale = Locales::findOrFail($request->langid);
            addlog(tc('lang.edited.msg'),'500');
            session()->flash('success', tc('lang.edited.msg'));
        }
        $locale->name = $request->name;
        $locale->locale = $request->key;

        if($request->active){
            $locale->active = 1;
        } else {
            if($request->langid) {
                $checkfed = Locales::where('id', $request->langid)->first();

                if ($checkfed->default != 1 and $checkfed->admin_default != 1) {
                    $locale->active = 0;
                }
            } else{
                $locale->active = 0;
            }
        }
        if($request->mdefault){
            if($request->langid){
                $locale->active = 1;
                $chk = Locales::where('id',$request->langid)->first();
                if($chk->default == 0){
                    $defaultm =  Locales::where('default',1)->first();
                    $defaultm->default = 0;
                    $defaultm->save();
                    $locale->default = 1;
                }
            }
        }
        if($request->cdefault){
            if($request->langid){
                $locale->active = 1;
                $chek = Locales::where('id',$request->langid)->first();
                if($chek->admin_default == 0){
                    $defaultc =  Locales::where('admin_default',1)->first();
                    $defaultc->admin_default = 0;
                    $defaultc->save();
                    $locale->admin_default = 1;
                }
            }
        }

        $locale->save();



        return redirect()->route('cms.settings');

    }

    public function removelang(Request $request)
    {

        if($request->dellangid){
            $locallang = Locales::where('id',$request->dellangid)->first();
            addlog(tc('lang.removed.msg') . ' '.$locallang->name,'600');
            $locallang->delete();
        }
        session()->flash('success', tc('lang.removed.msg'));
        return redirect()->route('cms.settings');

    }


    public function edittranslations(Request $request)
    {


        $trans = TranslationsCms::where('trans_key',$request->key)->get();

        return $trans;


    }

    public function edittranssave(Request $request)
    {
        $locales = getLocales();


        if($request->oldtranskey != null) {
            foreach ($locales as $l){
                $trans = TranslationsCms::where('trans_key',$request->oldtranskey)->where('locale',$l->locale)->first();

                if(empty($trans->trans_key)){
                    $trans = New TranslationsCms();
                    $trans->locale = $l->locale;
                    $trans->trans_key = $request->input('key');
                    $trans->value = $request->input('trans_'.$l->locale);
                    $trans->save();
                } else {
                    $trans->trans_key = $request->input('key');
                    $trans->value = $request->input('trans_'.$l->locale);
                    $trans->save();
                }

            }
            addlog(tc('translation.edited.msg') . ' '.$trans->trans_key,'500');

            session()->flash('success', tc('translation.edited.msg'));
            return redirect()->route('cms.settings');
        } else {

            $chk = TranslationsCms::where('trans_key', $request->input('key'))->first();
            if (empty($chk->value)) {

                foreach ($locales as $l) {
                    $trans = New TranslationsCms();
                    $trans->locale = $l->locale;
                    $trans->trans_key = $request->input('key');
                    $trans->value = $request->input('trans_' . $l->locale);
                    $trans->save();
                }
                addlog(tc('translation.added.msg') . ' '.$trans->trans_key,'400');

                session()->flash('success', tc('translation.added.msg'));
                return redirect()->route('cms.settings');
            } else {

                addlog(tc('key.unique.error.msg') ,'200');
                session()->flash('error', tc('key.unique.error.msg'));
                return redirect()->route('cms.settings');
            }

        }

    }

    public function rmtranslate(Request $request)
    {

        if($request->trkey){
            TranslationsCms::where('trans_key',$request->trkey)->delete();


        }

        addlog(tc('translation.removed.msg') ,'600');
        session()->flash('success', tc('translation.removed.msg'));
        return redirect()->route('cms.settings');

    }


    public function minify(Request $request)
    {
        $mini = Config::where('config_key','minify')->first();

        if($request->go == 1){
            $mini->value = 1;
            $mini->save();

        }
        if($request->go == 0){
            $mini->value = 0;
            $mini->save();
        }


        return [$request->go];
    }

    public function devmode(Request $request)
    {
        Maintenance::where('id','>',0)->delete();
        $ips =  (explode(",",$request->ips));

        foreach ($ips as $ip){
            $newip = New Maintenance();
            $newip->ip = $ip;
            $newip->save();
        }

        if($request->enable){
            $devmodeenable = Config::where('config_key','maintenanace')->first();
            $devmodeenable->value = 1;
            $devmodeenable->save();

            addlog(tc('maintenance.mode.enb.msg') ,'700');

            session()->flash('success', tc('maintenance.mode.enb.msg'));
        } else {
            $devmodeenable = Config::where('config_key','maintenanace')->first();
            $devmodeenable->value = 0;
            $devmodeenable->save();
            addlog(tc('maintenance.mode.dsb.msg') ,'800');

            session()->flash('success', tc('maintenance.mode.dsb.msg'));
        }


        return redirect()->route('cms.settings');

    }



    public function chkuser(Request $request)
    {
        $users = User::where('email',$request->email)->first();

        if(empty($users->email)){
            return ['go'=>true];
        } else {

            return ['go'=>false];
        }

    }



}
