<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Card;
use App\Models\Category;
use App\Models\Department;
use Illuminate\Support\Carbon;

class CardController extends Controller
{
    public function __construct()
    {
        $this->middleware('permission:card-list|card-create|card-edit|card-delete', ['only' => ['index','getCardsForAjax']]);
        $this->middleware('permission:card-create', ['only' => ['addCard']]);
        $this->middleware('permission:card-edit', ['only' => ['edit','updateCard']]);
        $this->middleware('permission:card-delete', ['only' => ['SoftDelete']]);
    }

    public function index()
    {
        $cards = Card ::all();
        $departaments = Department::all();

        return view('cards.index', compact('departaments'));
    }

    public function getCardsForAjax(Request $request)
    {
        if ($request->ajax()){
            return Datatables()->of(Card::all())
                ->addIndexColumn()

                ->addColumn('action', function($data){

                    $editUrl = url('edit-todo/'.$data->id);
//                    $btn = $btn. '<a href="'.$editUrl.'" data-toggle="tooltip" data-original-title="Edit" class="edit btn btn-primary btn-sm">Edit</a>';
                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="'.url(currentLocale().'/cards/print/'.$data->id).'" ><i class="fa fa-print"></i></a>';
//                    $btn = $btn. ' <a class="btn btn-info shadow btn-xs sharp mr-1" href="'.url('cards/'.$data->id).'" onclick="editDomain('.$data->id.')"><i class="fa fa-eye"></i></a>';
                    if (currentUser()->can('card-edit')){
                        $btn = $btn. ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editCard('.$data->id.')"><i class="fa fa-edit"></i></a>';
                    }
                    if (currentUser()->can('card-delete')){
                        $btn = $btn. ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteCard('.$data->id.')"><i class="fa fa-trash"></i></a>';
                    }

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }else{
            abort(404);
        }
    }

    public function create()
    {
        $cards = Card::all();
        $categories = Category::all();
        return view('cards.add', compact('cards','categories'));
    }

    public function addCard(Request $request)
    {
        try {
            Card::create($request->except('card_id'));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'id_number' => 'required',
            'name' => 'required|unique:cards|max:255',
            'surname' => 'required|max:25',
            'position' => 'required|max:25',
            'card_number' => 'required|unique:cards|min:4',
        ]);

        Card::insert([

            'id_number' => $request->id_number,
            'name' => $request->name,
            'surname' => $request->surname,
            'department_id' => $request->department_id,
            'position' => $request->position,
            'card_number' => $request->card_number,
            // 'user_id' => Auth::user()->id,
            // 'created_at' => Carbon::now(),

        ]);

        // return Redirect()->back()->with('success','Card Info Added');
        return Redirect()->route('cards')->with('success','Card Info Added');
        // return redirect()->route('cards')->with('success','Card Info Added');
    }

    // public function show(Card $card)
    // {
    //     return view('backend.cards.show',compact('card'));

    // }
    public function show($locale = 'ka',$id)
    {
        $card = Card::findOrFail($id);
        return view('cards.show',['card'=> $card]);

    }
    public function printCard($locale = 'ka',$id)
    {
        $card = Card::findOrFail($id);
//        return $card;
        return view('cards.print',['card'=> $card]);

    }

    public function edit($locale = 'ka',$id)
    {

        $card = Card::findOrFail($id);

        return jsonResponse($card);

    }

    public function updateCard($locale = 'ka',Request $request)
    {
        try {
            Card::findOrFail($request->card_id)->update($request->except('card_id'));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }

    }

    public function SoftDelete($locale = 'ka',$id)
    {
        Card::findOrFail($id)->delete();
        return jsonResponse(['status' => 1]);
    }

    public function destroy($id)
    {
        //
    }

}
