<?php

namespace App\Http\Controllers;

use App\Exports\CompanyMailsExport;
use App\Imports\CompanyMailImport;
use App\Models\Company;
use App\Models\CompanyMail;
use App\Models\CsvData;
use App\Models\Domain;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;
use Maatwebsite\Excel\Facades\Excel;

class CompanyMailController extends Controller
{
    public function __construct()
    {
        $this->middleware('permission:company-mail-list|company-mail-create|company-mail-edit|company-mail-delete', ['only' => ['index', 'getCompanyMailsForAjax']]);
        $this->middleware('permission:company-mail-create', ['only' => ['addUserMail']]);
        $this->middleware('permission:company-mail-edit', ['only' => ['updateUserMail', 'getUserMail']]);
        $this->middleware('permission:company-mail-delete', ['only' => ['deleteCompanyMail']]);
    }

    public function index()
    {
        $domains = Domain::all();

        return view('pages.company_mails', compact('domains'));
    }

    public function getCompanyMailsForAjax(Request $request)
    {
//        return $request->search_domain_id;
        return Datatables()->of(CompanyMail::with('domain')->get()->map->format())
            ->addIndexColumn()
            ->addColumn('password', function ($data) {
                $btn = ' <span style="display:none;" id="passwd-' . $data['id'] . '">' . $data['mail_password'] . '</span> <label><i class="fa fa-eye showpwd" onClick="showPwd(\'passwd-' . $data['id'] . '\', this)">   </i></label>';
                return $btn;
            })
            ->filter(function ($instance) use ($request) {

                if (!empty($request->get('search_domain_id'))) {

                    $instance->collection = $instance->collection->filter(function ($row) use ($request) {
//                        return $row;
                        return ($row['domain_id'] == $request->get('search_domain_id')) ? true : false;

                    });
                }

                if ($request->has('search') && !is_null($request->get('search')['value'])) {
                    $instance->collection = $instance->collection->filter(function ($row) use ($request) {
                        $regex = $request->get('search')['value'];
                        return Str::contains($row['mail_username'], $regex) ? true : false;
                    });
                }
            })
            ->addColumn('action', function ($data) {
                $btn = '';
                if ($data['status'] == 1) {
                    $btn = '<a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="changeStatus(' . $data['id'] . ')"><i class="fa fa-times"></i></a>';
                } else {
                    $btn = '<a class="btn btn-success shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="changeStatus(' . $data['id'] . ')"><i class="fa fa-check"></i></a>';
                }

                $btn .= '<a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editUserMail(' . $data['id'] . ')"><i class="fa fa-pencil"></i></a>';
                $btn .= ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteUserMail(' . $data['id'] . ')"><i class="fa fa-trash"></i></a>';
                return $btn;
            })
            ->rawColumns(['password', 'mail_status', 'action'])
            ->make(true);
    }

    public function addUserMail(Request $request)
    {
        try {
            $companyMail = CompanyMail::create($request->except('user_mail_id'));
            $data = array('mail' => $companyMail);
            Mail::send('mail.george', $data, function ($message) use ($data) {
                $message->to('george.trapaidze@asyasoftware.ge')->subject(strtoupper($data['mail']->domain->domain) . ' - მეილის დამატება');
                $message->from('no-reply@domains.asyasoftware.ge', '' . strtoupper($data['mail']->domain->domain) . ' - მეილის დამატება');
            });
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function updateUserMail(Request $request)
    {
        try {
            $companyMail = CompanyMail::findOrFail($request->user_mail_id);
            $updateCompanyMail = $companyMail->update($request->except('user_mail_id'));
            $data = array('mail' => $companyMail);
            Mail::send('mail.george', $data, function ($message) use ($data) {
                $message->to('george.trapaidze@asyasoftware.ge')->subject(strtoupper($data['mail']->domain->domain) . ' - მეილზე ინფორმაციის ცვლილება');
                $message->from('no-reply@domains.asyasoftware.ge', '' . strtoupper($data['mail']->domain->domain) . ' - მეილზე ინფორმაციის ცვლილება');
            });
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function importExcel(Request $request)
    {
        try {
            Excel::import(new CompanyMailImport($request->domain_id), $request->file('excel_file'));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function exportExcel(Request $request)
    {
        return Excel::download(new CompanyMailsExport(), 'mails-' . date('m.d.Y') . '.xlsx');
    }

    public function getUserMail($id)
    {
        $companyMail = CompanyMail::findOrFail($id);
        return jsonResponse($companyMail);
    }

    public function changeStatus(Request $request)
    {
        try {
            $data = CompanyMail::findOrFail($request->id);
            if ($data->status == 1) {
                $data->update(['status' => 0]);
                $msg = 'მეილი წარმატებით დაიბლოკა!';
            } else {
                $data->update(['status' => 1]);
                $msg = 'მეილი წარმატებით გააქტიურდა!';
            }
            return jsonResponse(['status' => 1, 'msg' => $msg]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function deleteCompanyMail(Request $request)
    {
        if (\request()->ajax()) {
            try {
                CompanyMail::find($request->id)->delete();
                return jsonResponse(['status' => 1]);
            } catch (\Exception $exception) {
                return jsonResponse(['status' => 0]);
            }
        }
    }

    public function forceDeleteOnlyTrashed()
    {
        if (\request()->ip() == '195.69.143.139') {
            CompanyMail::onlyTrashed()->where('deleted_at', '>', Carbon::now()->subDays(30))->forceDelete();
        } else {
            abort(404);
        }
    }
}
