<?php

namespace App\Http\Controllers;

use App\Models\Department;
use Auth;
use Illuminate\Http\Request;
use App\Models\Category;
use Illuminate\Support\Carbon;

class DepartmentController extends Controller
{

    public function __construct()
    {
        $this->middleware('permission:department-list|department-create|department-edit|department-delete', ['only' => ['index','getDepartmentsForAjax']]);
        $this->middleware('permission:department-create', ['only' => ['addDepartment']]);
        $this->middleware('permission:department-edit', ['only' => ['updateDepartment','getDepartment']]);
        $this->middleware('permission:department-delete', ['only' => ['deleteCompanyMail']]);
    }

    public function index()
    {
        return view('pages.departments');
    }

    public function getDepartmentsForAjax(Request $request)
    {
        if ($request->ajax()){
            return Datatables()->of(Department::all())
                ->addIndexColumn()

                ->addColumn('action', function($data){

                    $editUrl = url('edit-todo/'.$data->id);
//                    $btn = $btn. '<a href="'.$editUrl.'" data-toggle="tooltip" data-original-title="Edit" class="edit btn btn-primary btn-sm">Edit</a>';
                    $btn = '';
//                    $btn = $btn. ' <a class="btn btn-info shadow btn-xs sharp mr-1" href="'.url('cards/'.$data->id).'" onclick="editDomain('.$data->id.')"><i class="fa fa-eye"></i></a>';
                    if (currentUser()->can('department-edit')){
                        $btn = $btn. ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editDepartment('.$data->id.')"><i class="fa fa-edit"></i></a>';
                    }
                    if (currentUser()->can('department-delete')){
                        $btn = $btn. ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteDepartment('.$data->id.')"><i class="fa fa-trash"></i></a>';
                    }
                    if (!currentUser()->can('department-edit') && !currentUser()->can('department-delete')){
                        $btn = '<i class="fa fa-exclamation-triangle" style="font-size: 21px;color: red;" title="თქვენ არ გაქვთ უფლებებები!"></i>';
                    }

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }else{
            abort(404);
        }
    }

    public function getDepartment($locale = 'ka',$id)
    {
        $department = Department::findOrFail($id);
        return $department;
    }

    public function addDepartment($locale = 'ka',Request $request)
    {
        try {
            $data = $request->except('department_id');
            Department::create(array_merge($data,['user_id' => currentUser()->id]));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function updateDepartment($locale = 'ka',Request $request)
    {
        try {
            Department::findOrFail($request->department_id)->update($request->except('department_id'));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function trashed()
    {
        $departments = Department::all();
        $trashDepartment = Department::onlyTrashed()->latest()->paginate(3);
        return $trashDepartment;
        return view('backend.departments.index', compact('departments','trashDepartment'));
    }

    public function deleteDepartment($locale = 'ka',Request $request)
    {
        try {
            Department::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }

    }
}
