<?php

namespace App\Http\Controllers;

use App\Models\Company;
use App\Models\CompanyMail;
use App\Models\Domain;
use App\Models\DomainList;
use App\Models\DomainToken;
use App\Models\Task;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class DomainController extends Controller
{
    public function __construct()
    {
        $this->middleware('permission:domain-list|domain-create|domain-edit|domain-delete', ['only' => ['index', 'getDomainsForAjax']]);
        $this->middleware('permission:domain-create', ['only' => ['addDomain']]);
        $this->middleware('permission:domain-edit', ['only' => ['getDomainById', 'editDomain']]);
        $this->middleware('permission:domain-delete', ['only' => ['deleteDomain']]);
    }

    public function index()
    {
        $domains = Domain::select('owner')->distinct()->get();
        $companies = Company::all();
        return view('pages.domains.index', compact('domains', 'companies'));
    }

    public function show($id)
    {
        $domain = Domain::with('mails')->findOrFail($id);
        $participants = CompanyMail::where('is_notifiable', 1)->where('domain_id', $id)->get();
        $accepted = DomainList::where('activate', 1)->where('domain_id', $id)->get();
//        return $participants;
        return view('pages.domains.view', compact('domain', 'participants', 'accepted'));
    }

    public function sendEmailDomainExpire()
    {
        if (\request()->ip() == '195.69.143.139') {
            $domains = DB::select(DB::raw("SELECT * FROM domains WHERE DATEDIFF(CURDATE(), expire_date) <= 0 AND DATEDIFF(CURDATE(), expire_date) >= -10 AND deleted_at IS NULL"));
            if (count($domains) >= 1) {
                $users = User::where('domain', 1)->get();
                foreach ($users as $user) {
                    $data = array('domains' => $domains, 'full_name' => $user->full_name, 'email' => $user->email);
                    Mail::send('pages.mail', $data, function ($message) use ($data) {
                        $message->to($data['email'])->subject('Asyasoftware - დომენები');
                        $message->from('no-reply@domains.asyasoftware.ge', 'Asyasoftware - დომენები');
                    });
                }
            }
        } else {
            abort(403);
        }
    }

    public function sendDomainExpireCompanyMails()
    {
        if (\request()->ip() == '195.69.143.139') {
            $users = CompanyMail::where('is_notifiable', 1)->get();
//        return $users;
//        return $users;
            foreach ($users as $user) {

                $domains = DB::select(DB::raw("SELECT * FROM domains WHERE DATEDIFF(CURDATE(), expire_date) <= 0 AND DATEDIFF(CURDATE(), expire_date) >= -10 AND owner = '" . $user->owner . "' ORDER BY owner ASC"));

                if (count($domains) >= 1) {
                    $token = Str::random(100);
                    $domainToken = DomainToken::create(['token' => $token, 'company' => $user->owner]);
                    foreach ($domains as $domain) {
                        $arr = [
                            'token_id' => $domainToken->id,
                            'domain_id' => $domain->id,
                        ];
                        DomainList::create($arr);
                    }
                    $data = array('domains' => $domains, 'owner' => $user->owner, 'email' => $user->full_mail_username, 'token' => $token);
                    Mail::send('mail.company_mail', $data, function ($message) use ($data) {
                        $message->to($data['email'])->subject($data['owner'] . ' - დომენები');
                        $message->from('no-reply@domains.asyasoftware.ge', '' . $data['owner'] . ' - დომენები');
                    });
                }

            }
        } else {
            abort(403);
        }
    }

    public function senddd()
    {
        if (\request()->ip() == '195.69.143.139') {
            $users = CompanyMail::where('is_notifiable', 1)->get();
//        return $users;
//        return $users;
            foreach ($users as $user) {

                $domains = DB::select(DB::raw("SELECT * FROM domains WHERE DATEDIFF(CURDATE(), expire_date) <= 0 AND DATEDIFF(CURDATE(), expire_date) >= -10 AND owner = '" . $user->owner . "' ORDER BY owner ASC"));

                if (count($domains) >= 1) {
                    $token = Str::random(100);
                    $domainToken = DomainToken::create(['token' => $token, 'company' => $user->owner]);
                    foreach ($domains as $domain) {
                        $arr = [
                            'token_id' => $domainToken->id,
                            'domain_id' => $domain->id,
                        ];
                        DomainList::create($arr);
                    }
                    $data = array('domains' => $domains, 'owner' => $user->owner, 'email' => $user->full_mail_username, 'token' => $token);
                    Mail::send('mail.company_mail', $data, function ($message) use ($data) {
                        $message->to($data['email'])->subject($data['owner'] . ' - დომენები');
                        $message->from('no-reply@domains.asyasoftware.ge', '' . $data['owner'] . ' - დომენები');
                    });
                }

            }
        } else {
            abort(403);
        }
    }

    public function acceptDomainList(Request $request)
    {
        try {
            $ids = $request->ids;
            DomainList::whereIn('id', explode(",", $ids))->update(['activate' => 1, 'name' => $request->name, 'surname' => $request->surname, 'email' => $request->email]);
            $domains = DomainList::with('domain')->whereIn('id', explode(",", $ids))->get();
            $data = array('domains' => $domains, 'email' => 'giorgi.devadze@asyasoftware.ge');
            Mail::send('mail.accepted_domain_lists', $data, function ($message) use ($data) {
                $message->to($data['email'])->subject('დომენები');
                $message->from('no-reply@domains.asyasoftware.ge', 'დომენები');
            });
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function getDomainsForAjax(Request $request)
    {
        return Datatables()->of(Domain::all())
            ->addIndexColumn()
            ->addColumn('domain', function ($data) {
                return $data->domain . ' <a target="_blank" href="https://' . $data->domain . '"><i class="fa fa-external-link"></i></a>';
            })
            ->filter(function ($instance) use ($request) {

                if (!empty($request->get('company'))) {

                    $instance->collection = $instance->collection->filter(function ($row) use ($request) {

                        return Str::contains($row['owner'], $request->get('company')) ? true : false;

                    });
                }

                if (!empty($request->get('domain_registrator'))) {

                    $instance->collection = $instance->collection->filter(function ($row) use ($request) {

                        return Str::contains($row['domain_registrator'], $request->get('domain_registrator')) ? true : false;

                    });
                }

                if ($request->has('search') && !is_null($request->get('search')['value'])) {
                    $instance->collection = $instance->collection->filter(function ($row) use ($request) {
                        $regex = $request->get('search')['value'];
                        return Str::contains($row['domain'], $regex) ? true : false;
                    });
                }
            })
            ->addColumn('finished', function ($data) {
                return $data->corporate_mail_id;
            })
            ->addColumn('diffDays', function ($data) {
                $dt = Carbon::now();

                if ($dt->today()->toDateString() > $data->expire_date) {
                    return '<span style="color: red">ვადაგასული</span>';
                }
                $date = Carbon::parse($data->expire_date);
                return $date->diffInDays() . ' დღე';

            })
            ->addColumn('action', function ($data) {
                $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url('/domains/show/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';
                $btn = $btn . ' <a class="btn btn-success shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="updateDomain(' . $data->id . ')"><i class="fa fa-check"></i></a>';
                $btn = $btn . ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editDomain(' . $data->id . ')"><i class="fa fa-edit"></i></a>';
                $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteDomain(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                return $btn;
            })
            ->rawColumns(['domain', 'ns', 'finished', 'diffDays', 'action'])
            ->make(true);

    }

    public function updateDomain(Request $request)
    {
        try {
            $expireDate = Carbon::parse($request->expire_date)->format('Y-m-d');
            Domain::findOrFail($request->domain_id)->update(array_merge($request->except('domain_id'), ['expire_date' => $expireDate]));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function addDomain(Request $request)
    {
        try {
            $expireDate = Carbon::parse($request->expire_date)->format('Y-m-d');
            Domain::create(array_merge($request->except('domain_id'), ['expire_date' => $expireDate]));
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }

    public function updateDomainExpireDate(Request $request)
    {

        $domainFind = Domain::findOrFail($request->id);
        $dt = Carbon::now();

        if ($dt->today()->toDateString() > $domainFind->expire_date) {
            $domainFind->update(['expire_date' => Carbon::now()->addDays(365)]);
            return jsonResponse(['status' => 1]);
        }
        $updated = Carbon::parse($domainFind->expire_date)->addDays(365);
        $domainFind->update(['expire_date' => $updated]);
        return jsonResponse(['status' => 1]);
    }

    public function getDomainById($id)
    {
        $domain = Domain::findOrFail($id);
        return jsonResponse($domain);
    }

    public function deleteDomainExpCompanyMail(Request $request)
    {
        try {
            CompanyMail::findOrFail($request->id)->update(['is_notifiable' => 0]);
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }

    }

    public function deleteDomain(Request $request)
    {
        try {
            Domain::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception) {
            return jsonResponse(['status' => 0]);
        }
    }
}
