<?php

namespace App\Http\Controllers;

use App\Models\Invoice;
use App\Models\InvoiceItem;
use Carbon\Carbon;
use Carbon\Exceptions\Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use PDF;

class InvoiceController extends Controller
{
    public function index()
    {
        return view('pages.invoices.index');
    }

    public function show()
    {
        return view('pages.invoices.show');
    }

    public function createInvoiceItem()
    {
        return view('pages.invoices.create');
    }

    public function invoicesAjax(Request $request)
    {
        if ($request->ajax()){
            return Datatables()->of(Invoice::all())
                ->addIndexColumn()

                ->addColumn('action', function($data){

                    $editUrl = url('edit-todo/'.$data->id);
//                    $btn = $btn. '<a href="'.$editUrl.'" data-toggle="tooltip" data-original-title="Edit" class="edit btn btn-primary btn-sm">Edit</a>';
                    $btn = '';
                    $btn = $btn. '<a class="btn btn-info shadow btn-xs sharp mr-1" href="'.url('invoices/view/'.$data->id).'" onclick="editDomain('.$data->id.')"><i class="fa fa-eye"></i></a>';
                    if (currentUser()->can('invoice-edit')){
                        $btn = $btn. ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editInvoice('.$data->id.')"><i class="fa fa-edit"></i></a>';
                    }
//                    if (currentUser()->can('invoice-delete')){
                        $btn = $btn. ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteInvoice('.$data->id.')"><i class="fa fa-trash"></i></a>';
//                    }

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }else{
            abort(404);
        }
    }

    public function invoiceItemsAjax(Request $request)
    {
        if ($request->ajax()){
            return Datatables()->of(InvoiceItem::where('invoice_id',$request->id)->get())
                ->addIndexColumn()

                ->addColumn('action', function($data){

                    $editUrl = url('edit-todo/'.$data->id);
//                    $btn = $btn. '<a href="'.$editUrl.'" data-toggle="tooltip" data-original-title="Edit" class="edit btn btn-primary btn-sm">Edit</a>';
                    $btn = '';
//                    $btn = $btn. ' <a class="btn btn-info shadow btn-xs sharp mr-1" href="'.url('cards/'.$data->id).'" onclick="editDomain('.$data->id.')"><i class="fa fa-eye"></i></a>';
                    if (currentUser()->can('invoice-item-edit')){
                        $btn = $btn. ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editDepartment('.$data->id.')"><i class="fa fa-edit"></i></a>';
                    }
                    if (currentUser()->can('invoice-item-delete')){
                        $btn = $btn. ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteDepartment('.$data->id.')"><i class="fa fa-trash"></i></a>';
                    }
                    if (!currentUser()->can('invoice-item-edit') && !currentUser()->can('invoice-item-delete')){
                        $btn = '<i class="fa fa-exclamation-triangle" style="font-size: 21px;color: red;" title="თქვენ არ გაქვთ უფლებებები!"></i>';
                    }

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }else{
            abort(404);
        }
    }

    public function getPdf($id)
    {
        $invoice = Invoice::with('invoice_items')->findOrFail($id);
        $pdf = PDF::loadView('pages.invoices.pdf', compact('invoice'),[],['title' => 'invoice-'.$invoice->reference_no.'']);
        return $pdf->stream('invoice-'.$invoice->reference_no.'.pdf');
    }

    public function storeInvoice(Request $request)
    {
        try {
            $data = $request->except('invoice_id');
            $referenceNo = Invoice::where(DB::raw('YEAR(date)'),DB::raw('YEAR(CURDATE())'))->count();
            $sum = date('Y') .'-'. str_pad($referenceNo+1,3,'0',STR_PAD_LEFT);
            $date = Carbon::today();
            if ($request->date){
                $date = Carbon::parse($request->date)->format('Y-m-d');
            }
            Invoice::create(array_merge($data,['reference_no' => $sum,'date' => $date]));
            return jsonResponse(['status' => 1]);
        }catch (\Exception $exception){
            errorSendTelegram($exception->getMessage());
            Log::error($exception->getMessage());
            return jsonResponse(['status' => 0]);
        }
    }

    public function storeInvoiceItem(Request $request)
    {
        $input = $request->all();
        $conditions = $input['product_detail'];
        foreach ($conditions as $key => $condition) {
            $invoiceItem = new InvoiceItem;
            $invoiceItem->invoice_id = $input['invoice_id'];
            $invoiceItem->product_detail = $input['product_detail'][$key];
            $invoiceItem->product_model = $input['product_model'][$key];
            $invoiceItem->piece = $input['piece'][$key];
            $invoiceItem->percent = $input['percent'][$key];
            $invoiceItem->unit_price = $input['unit_price'][$key];
            $invoiceItem->total_price = ($input['unit_price'][$key] + $input['unit_price'][$key] * $input['percent'][$key] / 100) * $input['piece'][$key];
            $invoiceItem->save();
        }
        return redirect(url('invoices'))->with('success','ინვოისში ნივთები წარმატებით დაემატა');
    }

    public function deleteInvoice(Request $request)
    {
        try {
            Invoice::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        }catch (\Exception $exception){
            errorSendTelegram($exception->getMessage());
            Log::error($exception->getMessage());
            return jsonResponse(['status' => 0]);
        }
    }
}
