<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\Location;
use App\Models\Task;
use App\Models\TaskAttachment;
use App\Models\TaskUser;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class TaskController extends Controller
{
    public function __construct()
    {

    }

    public function index()
    {
//        return Task::with('location')->get();
        $users = User::all();
        $locations = Location::all();
        return view('pages.tasks.index', compact('users', 'locations'));
    }

    public function getTasksForAjax(Request $request)
    {
        if ($request->ajax()) {
            return Datatables()->of(Task::with('location','user','participants')->get())
                ->addIndexColumn()
                ->addColumn('status', function ($data){
                    if ($data->status == 0){
                        return '<span class="badge badge-rounded badge-danger">შეუსრულებელი</span>';
                    }elseif ($data->status == 1){
                        return '<span class="badge badge-rounded badge-warning">მოლოდინი</span>';
                    }elseif ($data->status == 2){
                        return '<span class="badge badge-rounded badge-success">შესრულებული</span>';
                    }
                })
                ->addColumn('action', function ($data) {



                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url(currentLocale() . '/tasks/show/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';
//                    $btn = $btn. ' <a class="btn btn-info shadow btn-xs sharp mr-1" href="'.url('cards/'.$data->id).'" onclick="editDomain('.$data->id.')"><i class="fa fa-eye"></i></a>';
                    if (currentUser()->can('task-edit')) {
                        $btn = $btn . ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editTask(' . $data->id . ')"><i class="fa fa-edit"></i></a>';
                    }
                    if (currentUser()->can('task-delete')) {
                        $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteTask(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                    }

                    return $btn;
                })
                ->rawColumns(['status','action'])
                ->make(true);
        } else {
            abort(403);
        }
    }

    public function addTask(Request $request)
    {
        try {
            $data = $request->except('task_id','assigned_to');
            $task = Task::create(array_merge($data,['user_id' => currentUser()->id]));
            for ($i = 0; $i < count($request->assigned_to);$i++){
                TaskUser::create(['task_id' => $task->id,'user_id' => $request->post('assigned_to')[$i]]);
//                echo $this->getUserById($request->post('assigned_to')[$i]);
            }

            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function getUserById($id)
    {
        $user = User::findOrFail($id);
        return $user->id;
    }

    public function download($id)
    {
        $attach = TaskAttachment::findOrFail($id);

        return response()->download(storage_path("app/public/{$attach->file}"));
    }

    public function getTask($id)
    {
        try {
            $data = Task::with('participants')->findOrFail($id);
            return $data;
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function show($id)
    {
        $task = Task::with('participants','user','location')->findOrFail($id);
//        return $task;
        return view('pages.tasks.view', $task);
    }

    public function deleteTask(Request $request)
    {
        try {
            Task::findOrFail($request->id)->delete();
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }
}
