<?php

namespace App\Http\Controllers;

use App\Models\Company;
use App\Models\TaskAttachment;
use App\Models\TaskUser;
use App\Models\Todo;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class TodoController extends Controller
{
    public function index()
    {
        $users = User::all();
        $companies = Company::all();
        return view('pages.todos.index',compact('users','companies'));
    }

    public function getTodosForAjax(Request $request)
    {
        if ($request->ajax()) {
            return Datatables()->of(Todo::with('company')->get())
                ->addIndexColumn()
                ->addColumn('status', function ($data){
                    if ($data->status == 0){
                        return '<span class="badge badge-rounded badge-danger">შეუსრულებელი</span>';
                    }elseif ($data->status == 1){
                        return '<span class="badge badge-rounded badge-warning">მოლოდინი</span>';
                    }elseif ($data->status == 2){
                        return '<span class="badge badge-rounded badge-success">შესრულებული</span>';
                    }
                })
                ->addColumn('action', function ($data) {
                    $btn = ' <a class="btn btn-dark shadow btn-xs sharp mr-1" href="' . url('/todos/show/' . $data->id) . '" ><i class="fa fa-eye"></i></a>';
                    if ($data->status == 1){
                        $btn .= ' <a class="btn btn-success shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="finishTodo('.$data->id.')"><i class="fa fa-check"></i></a>';
                    }
                    if (currentUser()->can('task-edit')) {
                        $btn = $btn . ' <a class="btn btn-primary shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="editTask(' . $data->id . ')"><i class="fa fa-edit"></i></a>';
                    }
                    if (currentUser()->can('task-delete')) {
                        $btn = $btn . ' <a class="btn btn-danger shadow btn-xs sharp mr-1" href="javascript:void(0)" onclick="deleteTask(' . $data->id . ')"><i class="fa fa-trash"></i></a>';
                    }

                    return $btn;
                })
                ->rawColumns(['status','action'])
                ->make(true);
        } else {
            abort(403);
        }
    }

    public function getTodoAttachmentsForAjax(Request $request)
    {
        if ($request->ajax()) {
            return Datatables()->of(TaskAttachment::with('user')->where('task_id', 1)->get())
                ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $btn = ' <a class="btn btn-info shadow btn-xs sharp mr-1" href="' . url('/tasks/download/' . $data->id) . '" ><i class="fa fa-download"></i></a>';

                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        } else {
            abort(403);
        }
    }

    public function addTodo(Request $request)
    {
        try {
            $data = $request->except('task_id','assigned_to');
            $endDate = Carbon::parse($request->end_date)->format('Y-m-d');
            $task = Todo::create(array_merge($data,['user_id' => currentUser()->id,'end_date' => $endDate]));
            for ($i = 0; $i < count($request->assigned_to);$i++){
                TaskUser::create(['task_id' => $task->id,'user_id' => $request->post('assigned_to')[$i]]);
            }

            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }

    public function show($id)
    {
        $task = Todo::with('participants','user','company')->findOrFail($id);
        return view('pages.todos.view', $task);
    }

    public function fileUpload(Request $req){

        $fileModel = new TaskAttachment;

        if($req->file()) {
            $fileName = date('Y-m-d-H:i:s').'-file'.'.'.$req->file->getClientOriginalExtension();
            $filePath = $req->file('file')->storeAs('uploads', $fileName, 'public');

            $fileModel->task_id = $req->todo_id;
            $fileModel->user_id = currentUser()->id;
            $fileModel->file = $filePath;
            $fileModel->save();

            return jsonResponse(['status' => 1]);
        }
    }

    public function finishTodo(Request $request)
    {
        try {
            Todo::findOrFail($request->id)->update(['status' => 2]);
            return jsonResponse(['status' => 1]);
        } catch (\Exception $exception){
            return jsonResponse(['status' => 0]);
        }
    }
}
