<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\Activitylog\Traits\LogsActivity;

class CompanyMail extends Model
{
    use HasFactory, LogsActivity, SoftDeletes;

    protected $guarded = [];

    protected $appends = [
        'full_mail_username',
        'owner',
        'mail_status'
    ];

    protected static $logAttributes = ['domain_id', 'mail_username','mail_password'];

    public function domain()
    {
        return $this->belongsTo(Domain::class);
    }

    public function getFullMailUsernameAttribute()
    {
        $company = str_replace(' ', '', $this->domain->domain);
        return "{$this->mail_username}@".strtolower($company);
    }

    public function getMailStatusAttribute()
    {
        if ($this->status == 1){
            return '<span class="badge badge-rounded badge-success">აქტიური</span>';
        } else{
            return '<span class="badge badge-rounded badge-danger">დაბლოკილი</span>';
        }
    }

    public function getOwnerAttribute()
    {
        return $this->domain->owner;
    }

    public function format()
    {
        return [
            'id' => $this->id,
            'domain_id' => $this->domain_id,
            'company_name' => strtoupper($this->domain->domain),
            'mail_username' => $this->mail_username,
            'full_mail_username' => $this->getFullMailUsernameAttribute(),
            'status' => $this->status,
            'mail_status' => $this->getMailStatusAttribute(),
            'mail_password' => $this->mail_password,
        ];
    }
}
