<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\Activitylog\Traits\LogsActivity;

class Domain extends Model
{
    use HasFactory, LogsActivity, SoftDeletes;
    protected $appends = [
        'formatted_expire_date',
        'diff_days',
        'formatted_ns',
        'formatted_finished'
    ];
    protected $guarded = [];
    protected static $logAttributes = ['domain', 'domain_registrator','expire_date','ns', 'finished', 'corporate_mail_id','owner', 'original_price', 'price'];
    public function getFormattedExpireDateAttribute()
    {
        return Carbon::parse($this->expire_date)->format('d.m.Y');
    }

    public function getDiffDaysAttribute()
    {
        return Carbon::parse($this->expire_date)->diffInDays();
    }

    public function participants()
    {
        return $this->belongsToMany(CompanyMail::class,DomainUser::class,'domain_id');
    }

    public function mails()
    {
        return $this->hasMany(CompanyMail::class);
    }

    public function getFormattedNsAttribute()
    {
        if ($this->ns == 1){
            return '<i style="color: green;" class="fa fa-check"></i>';
        }else{
            return '<i style="color: red;" class="fa fa-times"></i>';
        }
    }

    public function getFormattedFinishedAttribute()
    {
        if ($this->finished == 1){
            return '<i style="color: green;" class="fa fa-check"></i>';
        }else{
            return '<i style="color: red;" class="fa fa-times"></i>';
        }
    }

//    public function getCorporateMailNameAttribute()
//    {
//        return $this->corporate_mail->mail_organization;
//    }
//
//    public function corporate_mail()
//    {
//        return $this->belongsTo(CorporateMail::class);
//    }


}
