<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Task extends Model
{
    use HasFactory, SoftDeletes;

    protected $guarded = [];

    protected $appends = [
        'formatted_task_start',
        'formatted_task_end',
        'status_badge'
    ];

    protected static $logAttributes = ['user_id', 'assigned_to','task_name','task_description', 'location_id', 'task_start','task_end', 'finished', 'reason','status'];

    public function getFormattedTaskStartAttribute()
    {
        return Carbon::parse($this->task_start)->format('d.m.Y H:i');
    }

    public function getFormattedTaskEndAttribute()
    {
        return Carbon::parse($this->task_end)->format('d.m.Y H:i');
    }

    public function getStatusBadgeAttribute()
    {
        if ($this->status == 0){
            return '<span class="badge badge-rounded badge-danger">შეუსრულებელი</span>';
        }elseif ($this->status == 1){
            return '<span class="badge badge-rounded badge-warning">მოლოდინი</span>';
        }elseif ($this->status == 2){
            return '<span class="badge badge-rounded badge-success">შესრულებული</span>';
        }
    }

    public function participants()
    {
        return $this->belongsToMany(User::class,TaskUser::class);
    }

    public function location()
    {
        return $this->belongsTo(Location::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }
}
