<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Todo extends Model
{
    use HasFactory, SoftDeletes;

    protected $guarded = [];
    protected $appends = [
        'formatted_end_date',
        'status_badge'
    ];

    public function company()
    {
        return $this->belongsTo(Company::class);
    }
    public function participants()
    {
        return $this->belongsToMany(User::class,TaskUser::class,'task_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function attachments()
    {
        return $this->hasMany(TaskAttachment::class);
    }

    public function getFormattedEndDateAttribute()
    {
        return Carbon::parse($this->end_date)->format('d.m.Y H:i');
    }

    public function getStatusBadgeAttribute()
    {
        if ($this->status == 0){
            return '<span class="badge badge-rounded badge-danger">შეუსრულებელი</span>';
        }elseif ($this->status == 1){
            return '<span class="badge badge-rounded badge-warning">მოლოდინი</span>';
        }elseif ($this->status == 2){
            return '<span class="badge badge-rounded badge-success">შესრულებული</span>';
        }
    }
}
