@extends('layouts.app')
@section('title',__('tasks'))
@section('content')
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-header">
                    @can('todo-add')
                        <button type="submit" onclick="addTask()" class="btn light btn-primary mb-2" id="addTask"><i
                                class="fa fa-plus mr-2" aria-hidden="true"></i>დამატება
                        </button>
                    @endcan
                </div>
                <div class="card-body">
                    {{--                    <h6 class="card-subtitle">With DataTables you can alter the ordering characteristics of the table at initialisation time.</h6>--}}
                    <div class="table-responsive">
                        <table id="tasks" class="display table table-striped table-bordered">
                            <thead>
                            <tr>
                                <th>ID</th>
                                <th>დავალება</th>
                                <th>კომპანია</th>
                                <th>დასრულების თარიღი</th>
                                <th>სტატუსი</th>
                                <th>მოქმედება</th>
                            </tr>
                            </thead>
                            <tbody>

                            </tbody>
                            <tfoot>
                            <tr>
                                <th>ID</th>
                                <th>დავალება</th>
                                <th>კომპანია</th>
                                <th>დასრულების თარიღი</th>
                                <th>სტატუსი</th>
                                <th>მოქმედება</th>
                            </tr>
                            </tfoot>
                        </table>
                    </div>
                </div>
            </div>
        </div>

    </div>
    <div class="modal fade" id="modal_form" tabindex="-1" role="dialog" aria-labelledby="exampleStandardModalLabel"
         aria-hidden="true">
        <div class="modal-dialog modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modal_title"></h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <form action="javascript:void(0)" id="task_form">
                        @csrf
                        <input type="hidden" id="task_id" name="task_id">
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="assigned_to">მომხმარებელი</label>
                                <select class="form-control selectpicker assigned_to" name="assigned_to[]" id="assigned_to"
                                        data-live-search="true" multiple>
                                    @foreach($users as $user)
                                        <option value="{{ $user->id }}">{{ $user->full_name }}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="form-group col-md-6">
                                <label for="assigned_to">კომპანია</label>
                                <select class="form-control selectpicker" name="company_id" id="company_id"
                                        data-live-search="true">
                                    @foreach($companies as $company)
                                        <option value="{{ $company->id }}">{{ $company->company_name }}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="form-group col-md-6">
                                <label for="task_name">დავალების სახელი</label>
                                <input type="text" class="form-control input-rounded" name="title" id="title"
                                       placeholder="დავალების სახელი">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="expire_date">დასრულების თარიღი</label>
                                <div class="input-group date" id="datetimepicker11" data-target-input="nearest">
                                    <input type="text" name="end_date" id="expire_date" class="form-control datetimepicker-input input-rounded" data-target="#datetimepicker11" />
                                    <div class="input-group-append" data-target="#datetimepicker11" data-toggle="datetimepicker">
                                        <div class="input-group-text"><i class="fa fa-calendar"></i></div>
                                    </div>
                                </div>
                            </div>
                            <div class="form-group col-md-12">
                                <label for="task_description">დავალების აღწერა</label>
                                <textarea name="description" id="text" placeholder="სრული ინფორმაცია" class="form-control" type="text"></textarea>
                            </div>
                        </div>

                </div>
                <div class="modal-footer">
                    <button type="submit" onclick="save()" class="btn btn-primary" id="btnSave"><i
                            class="fa fa-floppy-o mr-2" aria-hidden="true"></i>შენახვა
                    </button>
                    <button type="button" class="btn btn-danger" data-dismiss="modal"><i class="fa fa-times mr-2"
                                                                                         aria-hidden="true"></i>დახურვა
                    </button>
                </div>
                </form>
            </div>
        </div>
    </div>
    <script type="text/javascript">
        CKEDITOR.replace('text', {
            language: 'en'
        })
        $('#datetimepicker11').datetimepicker({
            format: 'DD.MM.YYYY H:m',
            locale: 'ka',
            minDate: new Date()
        });
    </script>
    <script>
        let table;
        let save_method;
        $(document).ready(function () {

            table = $('#tasks').DataTable({
                order: [ [0, 'desc'] ],
                processing: true,
                serverSide: true,
                ajax: {
                    url: "{{ url(currentLocale().'/todos/todos_ajax') }}",
                    type: 'GET',
                },
                columns: [
                    {data: 'DT_RowIndex', name: 'DT_RowIndex'},
                    {data: 'title', name: 'task_name'},
                    {data: 'company.company_name', name: 'company.company_name'},
                    {data: 'formatted_end_date', name: 'formatted_end_date'},
                    {data: 'status', name: 'status'},
                    {data: 'action', name: 'action'}
                ]
            });
        });

        function reload() {
            table.ajax.reload();
        }

        function addTask() {
            save_method = 'add';
            $('#task_form')[0].reset(); // reset form on modals
            $('.form-group').removeClass('has-error'); // clear error class
            $('.help-block').empty(); // clear error string
            $('#modal_form').modal('show'); // show bootstrap modal when complete loaded
            $('#modal_title').text(`დავალების დამატება`);
        }

        function editTask(id) {
            save_method = 'update';
            $('#task_form')[0].reset(); // reset form on modals
            $('.form-group').removeClass('has-error'); // clear error class
            $('.help-block').empty(); // clear error string
            $.ajax({
                url: "{{ url(currentLocale().'/tasks/get_task') }}/" + id,
                type: "GET",
                dataType: "JSON",
                success: function (data) {
                    $('#task_id').val(data.id);
                    let arr = [];
                    for (let i = 0;i < data.participants.length;i++){
                        arr.push(data.participants[i].id)
                    }
                    $('#assigned_to').selectpicker('val', arr);
                    $('#task_name').val(data.task_name)
                    CKEDITOR.instances['text'].setData(data.task_description);
                    // $('#task_description').val(data.task_description)
                    $('#location_id').val(data.location_id)
                    $('#task_start').val(data.task_start)
                    $('#task_end').val(data.task_end)
                    $('.selectpicker').selectpicker("refresh");
                    $('#modal_form').modal('show'); // show bootstrap modal when complete loaded
                    $('#modal_title').text(`დავალების რედაქტირება - ${data.task_name}`);
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    alert('Error get data from ajax');
                }
            });
        }

        function save() {
            let url;
            if (save_method === 'add') {
                url = '{{ url(currentLocale().'/todos/add_todo') }}'
            } else if (save_method === 'update') {
                url = '{{ url(currentLocale().'/domains/update_domain_info') }}'
            }
            for (instance in CKEDITOR.instances) {
                CKEDITOR.instances[instance].updateElement();
            }
            $('#btnSave').html('<i class="fas fa-spinner fa-spin mr-1"></i>დაელოდეთ...');
            $('#btnSave').attr('disabled', true);
            $.ajax({
                url: url,
                type: "POST",
                data: $('#task_form').serialize(),
                dataType: "JSON",
                success: function (data) {
                    if (data.status == 1) {
                        $('#modal_form').modal('hide');
                        Swal.fire('წარმატებული!', 'ინფორმაცია წარმარებით შეინახა!', 'success')
                        reload();
                    } else {
                        Swal.fire('შეცდომა!', '', 'error');
                    }
                    $('#btnSave').html('<i class="fa fa-floppy-o mr-1" aria-hidden="true"></i>შენახვა');
                    $('#btnSave').attr('disabled', false); //set button enable
                }
            });
        }

        function finishTodo(id) {
            Swal.fire({
                title: 'ნამდვილად გსურთ დავალების დასრულება?',
                text: "",
                icon: 'question',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'დიახ!',
                cancelButtonText: 'არა!',
                preConfirm: function () {
                    return new Promise(function (resolve) {
                        $('.swal2-confirm').html('<i class="fa fa-spinner fa-spin mr-1"></i>');
                        $.ajax({
                            url: "{{ url(currentLocale().'/todos/finish_todo') }}",
                            type: "POST",
                            dataType: "JSON",
                            data: {
                                '_token': '{{ csrf_token() }}',
                                'id': id
                            },
                        })
                            .done(function (response) {
                                if (response.status === 1) {
                                    reload()
                                    Swal.fire('წარმატებული!', 'დავალები წარმატებით წაიშალა', 'success');
                                } else {
                                    Swal.fire('Error!', 'Please try again', 'error');
                                }
                            })
                            .fail(function () {
                                Swal.fire('Oops...', 'Please try again!', 'error');
                            });
                    });
                },
                allowOutsideClick: true
            });
        }

        function deleteTask(id) {
            Swal.fire({
                title: 'ნამდვილად გსურთ დავალების წაშლა?',
                text: "",
                icon: 'question',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'დიახ!',
                cancelButtonText: 'არა!',
                preConfirm: function () {
                    return new Promise(function (resolve) {
                        $('.swal2-confirm').html('<i class="fa fa-spinner fa-spin mr-1"></i>');
                        $.ajax({
                            url: "{{ url(currentLocale().'/tasks/delete_task') }}",
                            type: "POST",
                            dataType: "JSON",
                            data: {
                                '_token': '{{ csrf_token() }}',
                                'id': id
                            },
                        })
                            .done(function (response) {
                                if (response.status === 1) {
                                    reload()
                                    Swal.fire('წარმატებული!', 'დავალები წარმატებით წაიშალა', 'success');
                                } else {
                                    Swal.fire('Error!', 'Please try again', 'error');
                                }
                            })
                            .fail(function () {
                                Swal.fire('Oops...', 'Please try again!', 'error');
                            });
                    });
                },
                allowOutsideClick: true
            });
        }

    </script>
@endsection
