<?php

use App\Exports\CompanyMailsExport;
use App\Http\Controllers\CardController;
use App\Http\Controllers\CompanyMailController;
use App\Http\Controllers\DepartmentController;
use App\Http\Controllers\DomainController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\ImportController;
use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\TaskController;
use App\Http\Controllers\TodoController;
use App\Http\Controllers\UserController;
use App\Models\DomainList;
use App\Models\IsOffline;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\RoleController;
use Illuminate\Support\Facades\Session;
use Maatwebsite\Excel\Facades\Excel;
use Spatie\Activitylog\Models\Activity;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::get('/off', function () {
    $isOffline = IsOffline::find(1)->format();
    if ($isOffline['status'] == 0 || currentUser()->is_admin === 1) {
        return redirect('/home');
    }
    return view('offline.index', compact('isOffline'));
});

Route::get('/', function () {
    if (Auth::check()) {
        return redirect('/dashboard');
    }
    return view('auth.login');
});

Route::get('/test_sql', function (){
    return DB::connection('sqlsrv')->table('userss')->select('*')->get();
//    if (DB::connection('sqlserv')->getDatabaseName()){
//        echo "connected";
//    }else{
//        echo 'sss';
//    }
});

Route::get('/storage-link',function (){
    \Illuminate\Support\Facades\Artisan::call('storage:link');
});

Route::get('/testunia', function (){
        return Excel::download(new \App\Exports\PayableDomainListExport(),'domains-'.date('m.d.Y').'.xlsx');
});

Route::get('/send', [DomainController::class, 'sendEmailDomainExpire']);
Route::get('/company_send_domain_exp', [DomainController::class, 'sendDomainExpireCompanyMails']);
Route::post('/accept_domain_list', [DomainController::class, 'acceptDomainList']);

Route::get('/domain_lists/{token}/{locale?}', function ($token, $locale = 'en'){
    \Illuminate\Support\Facades\App::setLocale($locale);
    $domainToken = \App\Models\DomainToken::where('token', $token)->latest()->firstOrFail();
    $domains = DomainList::with('domain')->where('token_id', $domainToken->id)->orderBy('activate','asc')->get();
    return view('pages.domains.company_domains_exp', compact('domains'));
});

Route::get('/force_delete_company_mails', [CompanyMailController::class,'forceDeleteOnlyTrashed']);

Route::get('locale/{locale}', function ($locale) {
    Session::put('locale', $locale);
    return redirect()->back();
});

//Route::group([
//    'prefix' => '{locale}',
//    'where' => ['locale' => '[a-zA-Z]{2}'],
//    'middleware' => 'setlocale'
//], function (){
    Route::middleware(['auth', 'offline'])->group(function () {
        Route::get('/dashboard', [HomeController::class,'index']);

        Route::get('/user', function (Request $request) {
            return $request->user();
        });

        Route::group(['prefix' => 'users'], function (){
            Route::get('/', [UserController::class,'index']);
            Route::get('/{id}/edit',[UserController::class,'edit']);
            Route::patch('/{id}/update',[UserController::class,'update']);
            Route::get('/{id}/show',[UserController::class,'show']);
            Route::get('/create',[UserController::class,'create']);
            Route::post('/store',[UserController::class,'store']);
            Route::get('/users_ajax', [UserController::class, 'getUsersForAjax']);
            Route::post('/delete_user', [UserController::class, 'deleteUser']);
        });

        Route::group(['prefix' => 'roles'], function (){
            Route::get('/', [RoleController::class,'index']);
            Route::get('/create', [RoleController::class,'create']);
            Route::post('/store',[RoleController::class,'store']);
            Route::get('/{id}/edit', [RoleController::class,'edit']);
            Route::patch('/{id}/update',[RoleController::class,'update']);
            Route::post('/delete_role',[RoleController::class,'deleteRole']);
        });

        Route::group(['prefix' => 'tasks'], function (){
            Route::get('/',[TaskController::class,'index']);
            Route::get('/tasks_ajax',[TaskController::class,'getTasksForAjax']);
            Route::post('/add_task',[TaskController::class,'addTask']);
            Route::get('/download/{id}',[TaskController::class,'download']);

            Route::post('/delete_task',[TaskController::class,'deleteTask']);
            Route::get('/get_task/{id}',[TaskController::class,'getTask']);
            Route::get('/show/{id}',[TaskController::class,'show']);
        });

        Route::group(['prefix' => 'todos'], function (){
            Route::get('/',[TodoController::class,'index']);
            Route::get('/todos_ajax',[TodoController::class,'getTodosForAjax']);
            Route::get('/todo_attachments_ajax',[TodoController::class,'getTodoAttachmentsForAjax']);
            Route::post('/add_todo',[TodoController::class,'addTodo']);
            Route::get('/show/{id}',[TodoController::class,'show']);
            Route::post('/upload_task_file', [TodoController::class, 'fileUpload']);

            Route::post('/finish_todo',[TodoController::class,'finishTodo']);
        });

        Route::group(['prefix' => 'invoices'], function (){
            Route::get('/',[InvoiceController::class,'index']);
            Route::get('/view/{id}',[InvoiceController::class,'show']);
            Route::get('/invoice_ajax',[InvoiceController::class,'invoicesAjax']);
            Route::get('/invoice_items_ajax',[InvoiceController::class,'invoiceItemsAjax']);
            Route::get('/pdf/{id}',[InvoiceController::class,'getPdf']);
            Route::get('/{id}/create',[InvoiceController::class,'createInvoiceItem']);
            Route::post('/store',[InvoiceController::class,'storeInvoice']);
            Route::post('/{id}/store',[InvoiceController::class,'storeInvoiceItem']);
            Route::post('/add_todo',[InvoiceController::class,'addTodo']);
//            Route::get('/show/{id}',[InvoiceController::class,'show']);
//            Route::post('/upload_task_file', [InvoiceController::class, 'fileUpload']);

            Route::post('/delete_invoice',[InvoiceController::class,'deleteInvoice']);
        });

        Route::group(['prefix' => 'cards'], function () {
            Route::get('/', [CardController::class, 'index'])->name('cards');
            Route::get('/cards_ajax', [CardController::class, 'getCardsForAjax']);

            Route::post('/add_card', [CardController::class, 'addCard']);
            Route::get('/{id}', [CardController::class, 'show']);
            Route::get('/print/{id}', [CardController::class, 'printCard']);
            Route::post('/store', [CardController::class, 'store'])->name('card.store');

            Route::get('/edit/{id}', [CardController::class, 'edit']);
            Route::post('/update_card', [CardController::class, 'updateCard']);
            Route::get('/delete_card/{id}', [CardController::class, 'SoftDelete']);
        });

        Route::group(['prefix' => 'departments'], function () {
            Route::get('/', [DepartmentController::class, 'index']);
            Route::get('/departments_ajax', [DepartmentController::class, 'getDepartmentsForAjax']);
            Route::get('/get_department/{id}', [DepartmentController::class, 'getDepartment']);
            Route::post('/add_department', [DepartmentController::class, 'addDepartment']);
            Route::post('/update_department', [DepartmentController::class, 'updateDepartment']);
            Route::post('/delete_department', [DepartmentController::class, 'deleteDepartment']);
        });

        Route::group(['prefix' => 'domains'], function () {
            Route::get('/', [DomainController::class, 'index']);
            Route::get('/show/{id}', [DomainController::class, 'show']);
            Route::get('/domains_ajax', [DomainController::class, 'getDomainsForAjax']);
            Route::post('/delete_domain', [DomainController::class, 'deleteDomain']);
            Route::get('/get_domain/{id}', [DomainController::class, 'getDomainById']);
            Route::post('/add_domain_info', [DomainController::class, 'addDomain']);
            Route::post('/update_domain_info', [DomainController::class, 'updateDomain']);
            Route::post('/update_domain_expire_date', [DomainController::class, 'updateDomainExpireDate']);
        });

        Route::group(['prefix' => 'company_mails'], function () {
            Route::get('/', [CompanyMailController::class, 'index']);
            Route::get('/company_mails_ajax', [CompanyMailController::class, 'getCompanyMailsForAjax']);
            Route::post('/delete_company_mail', [CompanyMailController::class, 'deleteCompanyMail']);
            Route::post('/status_change', [CompanyMailController::class, 'changeStatus']);
            Route::post('/add_user_mail', [CompanyMailController::class, 'addUserMail']);
            Route::post('/update_user_mail', [CompanyMailController::class, 'updateUserMail']);
            Route::get('/get_user_mail/{id}', [CompanyMailController::class, 'getUserMail']);
            Route::post('/import_excel', [CompanyMailController::class, 'importExcel']);
            Route::get('/export_excel', [CompanyMailController::class, 'exportExcel']);
        });

        Route::post('/notification', [UserController::class, 'changeNotification']);
        Route::get('/my-profile', function () {
            return view('pages.my_profile');
        });

        Route::get('/test', function () {
            return User::find(1)->authentications;
        });

        Route::get('/act', function () {
            $activity = Activity::all()->last();
            return $activity->changes();
        });

    });
//});

Auth::routes();

Route::get('/import', [ImportController::class,'index']);

Route::get('/home', [HomeController::class, 'index'])->name('home');
